summaryrefslogtreecommitdiffstats
path: root/kaudiocreator/job.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kaudiocreator/job.cpp')
-rw-r--r--kaudiocreator/job.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/kaudiocreator/job.cpp b/kaudiocreator/job.cpp
index c4950377..740aeb5e 100644
--- a/kaudiocreator/job.cpp
+++ b/kaudiocreator/job.cpp
@@ -21,7 +21,7 @@
#include <tqregexp.h>
/**
* A helper function to tqreplace %X with the stuff in the album.
* if quote is true then put "" around the %X
*/
TQString Job::replaceSpecialChars(const TQString &string, bool quote, TQMap<TQString, TQString> _map){
@@ -45,14 +45,14 @@ TQString Job::replaceSpecialChars(const TQString &string, bool quote, TQMap<TQSt
}
void Job::fix(const TQString &in, const TQString &out){
- track_title.tqreplace( TQRegExp(in), out );
- track_artist.tqreplace( TQRegExp(in), out );
- track_comment.tqreplace( TQRegExp(in), out );
+ track_title.replace( TQRegExp(in), out );
+ track_artist.replace( TQRegExp(in), out );
+ track_comment.replace( TQRegExp(in), out );
// year
// track
- genre.tqreplace( TQRegExp(in), out );
- album.tqreplace( TQRegExp(in), out );
- comment.tqreplace( TQRegExp(in), out );
- group.tqreplace( TQRegExp(in), out );
+ genre.replace( TQRegExp(in), out );
+ album.replace( TQRegExp(in), out );
+ comment.replace( TQRegExp(in), out );
+ group.replace( TQRegExp(in), out );
}
@@ -21,7 +21,7 @@
#include <tqregexp.h>
/**
- * A helper function to tqreplace %X with the stuff in the album.
+ * A helper function to replace %X with the stuff in the album.
* if quote is true then put "" around the %X
*/